class calculator:
    """ Класс для вычисления простых операций. """
    def __init__(self, num1, operator, num2):
        self.num1 = num1
        self.num2 = num2
        self.operator = operator

    def do(self):
        if not self.validate_data():
            raise TypeError("Ошибка: данные должны быть числовыми.")
        if self.operator == "+":
            return self.num1 + self.num2
        elif self.operator == "-":
            return self.num1 - self.num2
        elif self.operator == "*":
            return self.num1 * self.num2
        elif self.operator == "/":
            if self.num2 == 0:
                raise ZeroDivisionError("Ошибка: деление на ноль")
            else:
                return self.num1 / self.num2
        else:
            raise ValueError("Ошибка: недопустимый оператор")

    def validate_data(self):
        if not (isinstance(self.num1, (int, float))
                and isinstance(self.num2, (int, float))):
            return False
        return True



class bubblesort:
    """ Класс для работы сортировки пузырьком """
    def __init__(self, data):
        self.data = data

    def sort(self):
        if not self.validate_data():
            raise  TypeError("Ошибка: данные должны быть числовыми.")
        n = len(self.data)
        for i in range(n):
            for j in range(i + 1, n):
                if self.data[j] < self.data[i]:
                    self.data[i], self.data[j] = self.data[j], self.data[i]
        return self.data

    def validate_data(self):
        if not all(isinstance(item, (int, float)) for item in self.data):
            return False
        return True



class fibonacci:
    """ Класс для нахождения чисел Фибоначчи """
    def __init__(self, lenght):
        self.lenght = lenght

    def make(self):
        if not isinstance(self.lenght, int):
            raise TypeError("Ошибка: задаваемая длинна должна быть целым числом.")
        list = [0]
        for i in range(self.lenght - 1):
            if i == 0:
                list.append(list[i] + 1)
            else:
                list.append(list[i] + list[i - 1])
        return list




from setuptools import setup, find_packages

def readme():
  with open('README.md', 'r', encoding='utf-8') as f:
    return f.read()

setup(
  name='unexart_lib',
  version='0.0.1',
  author='unexart',
  author_email='unexart4132@gmail.com',
  description='This is the simplest module created for educational purposes.',
  long_description=readme(),
  long_description_content_type='text/markdown',
  url='https://github.com/UnexarT/unexart_lib',
  packages=find_packages(),
  install_requires=['requests>=2.25.1'],
  classifiers=[
    'Programming Language :: Python :: 3.9',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent'
  ],
  keywords='Fibonacci bubblesort calculator',
  project_urls={
    'GitHub': 'https://github.com/UnexarT/unexart_lib'
  },
  python_requires='>=3.6'
)